
@import "../mixins";
@import url(http://fonts.googleapis.com/css?family=Lato:400,700);

body {
    font-family: 'Lato', sans-serif !important;
}

h1, h2, h3, h4, h5, h6, p, div, span {
    font-family: 'Lato', sans-serif;
    font-weight: 400;
}

p, div, span, th, td {
    font-size: 16px;
}


.link {
    cursor: pointer;
}

#PostManager2 {
    .header {
       border-bottom: 5px solid #ccc;
       margin-bottom: 20px;
       @include clearfix;
    }
    .page-title {
        font-size: 32px;
        padding-bottom: 10px;

    }

    ul.menu {
        margin: 0px;
        border: 0px;
        list-style: none;
        @include clearfix;
        li {
            height: 40px;
            line-height: 40px;
            float: left;
            margin-left: 10px;
        }

    }

    .block-title {
        font-size: 18px;
        border-bottom: 1px dotted #ccc;
        padding-bottom: 2px;
        margin-bottom: 5px;
        margin-top: 30px;
    }
    .page-category,
    .page-type {
        ul.list {
            list-style: none;
            margin:0px;
            padding:0px;

            li {

                border-bottom: 1px dotted #ccc;
                padding: 10px;
                margin: 10px;
                cursor: pointer;
                span {
                    font-style: italic;
                }
            }
        }
    }
}
