.profile-pic-avatar {
  display: inline-block;
  width: 100px;
  height: 100px;
  border-radius: 50%;
  overflow: hidden;
  border: 4px solid #fff; }
  .profile-pic-avatar.size-50 {
    width: 50px !important;
    height: 50px !important; }
  .profile-pic-avatar.size-100 {
    width: 100px !important;
    height: 100px !important; }
  .profile-pic-avatar.size-150 {
    width: 150px !important;
    height: 150px !important; }
  .profile-pic-avatar.size-200 {
    width: 200px !important;
    height: 200px !important; }
  .profile-pic-avatar.size-250 {
    width: 250px !important;
    height: 250px !important; }
  .profile-pic-avatar.size-300 {
    width: 300px !important;
    height: 300px !important; }
  .profile-pic-avatar.size-350 {
    width: 350px !important;
    height: 350px !important; }
  .profile-pic-avatar img {
    max-width: 100%; }


.btn.social-login {
  border-radius: 0px !important;
  border: 0px !important;
  margin-bottom: 10px;
}